@@ -1,3 +1,15 @@
+# Copyright 2002 Ben Escoto
+#
+# This file is part of rdiff-backup.
+#
+# rdiff-backup is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, Inc., 675 Mass Ave, Cambridge MA
+# 02139, USA; either version 2 of the License, or (at your option) any
+# later version; incorporated herein by reference.
+
+"""Start (and end) here - read arguments, set global settings, etc."""
+
 import getopt, sys, re
 from log import *
 from lazy import *
@@ -10,10 +22,7 @@ from highlevel import *
 from manage import *
 import Globals, Time, SetConnections
 
-#######################################################################
-#
-# main - Start here: Read arguments, set global settings, etc.
-#
+
 action = None
 remote_cmd, remote_schema = None, None
 force = None
