@@ -1,9 +1,17 @@
+# Copyright 2002 Ben Escoto
+#
+# This file is part of rdiff-backup.
+#
+# rdiff-backup is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, Inc., 675 Mass Ave, Cambridge MA
+# 02139, USA; either version 2 of the License, or (at your option) any
+# later version; incorporated herein by reference.
+
+"""Manage logging, displaying and recording messages with required verbosity"""
+
 import time, sys, traceback, types
 
-#######################################################################
-#
-# log - Manage logging 
-#
 
 class LoggerError(Exception): pass
 
