@@ -1,11 +1,19 @@
+# Copyright 2002 Ben Escoto
+#
+# This file is part of rdiff-backup.
+#
+# rdiff-backup is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, Inc., 675 Mass Ave, Cambridge MA
+# 02139, USA; either version 2 of the License, or (at your option) any
+# later version; incorporated herein by reference.
+
+"""Read increment files and restore to original"""
+
 from __future__ import generators
 import tempfile
 from static import *
 
-#######################################################################
-#
-# restore - Read increment files and restore to original
-#
 
 class RestoreError(Exception): pass
 
